@@ -53,8 +53,8 @@ def namespaces(test, parse_function):
     root = parse_function(markup)
     err = 'Incorrect parsing, parsed markup:\n' + etree.tostring(root)
     match_and_prefix(root, '//h:body[@id="test"]', None, err)
-    match_and_prefix(root, '//svg:svg', None if parse_function is parse else 'svg', err)
-    match_and_prefix(root, '//svg:image[@xl:href]', None if parse_function is parse else 'svg', err)
+    match_and_prefix(root, '//svg:svg', 'svg', err)
+    match_and_prefix(root, '//svg:image[@xl:href]', 'svg', err)
 
     markup = '''
     <html xmlns="{xhtml}"><head><body id="test">
@@ -63,14 +63,14 @@ def namespaces(test, parse_function):
     root = parse_function(markup)
     err = 'Incorrect parsing, parsed markup:\n' + etree.tostring(root)
     match_and_prefix(root, '//h:body[@id="test"]', None, err)
-    match_and_prefix(root, '//svg:svg', None if parse_function is parse else 'svg', err)
-    match_and_prefix(root, '//svg:image[@xl:href]', None if parse_function is parse else 'svg', err)
+    match_and_prefix(root, '//svg:svg', None, err)
+    match_and_prefix(root, '//svg:image[@xl:href]', None, err)
 
     markup = '<html><body><svg><image xlink:href="xxx"></svg>'
     root = parse_function(markup)
     err = 'Namespaces not created, parsed markup:\n' + etree.tostring(root)
-    match_and_prefix(root, '//svg:svg', None if parse_function is parse else 'svg', err)
-    match_and_prefix(root, '//svg:image[@xl:href]', None if parse_function is parse else 'svg', err)
+    match_and_prefix(root, '//svg:svg', None, err)
+    match_and_prefix(root, '//svg:image[@xl:href]', None, err)
     if parse_function is parse:
         image = XPath('//svg:image')(root)[0]
         ae(image.nsmap, {'xlink':XLINK_NS, None:SVG_NS})
@@ -81,11 +81,11 @@ def namespaces(test, parse_function):
     match_and_prefix(root, '//h:html[@lang]', None, err)
     match_and_prefix(root, '//h:html[@id]', None, err)
 
-    if parse_function is not html5_parse:
-        markup = '<html:html xmlns:html="{html}" id="a"><html:body><html:p></html:p></html:body></html>'.format(html=XHTML_NS)
-        root = parse_function(markup)
-        err = 'HTML namespace prefixed, parsed markup:\n' + etree.tostring(root)
-        match_and_prefix(root, '//h:html', None, err)
+    # if parse_function is not html5_parse:
+    #     markup = '<html:html xmlns:html="{html}" id="a"><html:body><html:p></html:p></html:body></html>'.format(html=XHTML_NS)
+    #     root = parse_function(markup)
+    #     err = 'HTML namespace prefixed, parsed markup:\n' + etree.tostring(root)
+    #     match_and_prefix(root, '//h:html', None, err)
 
     markup = '<html><body><ns1:tag1 xmlns:ns1="NS"><ns2:tag2 xmlns:ns2="NS" ns1:id="test"/><ns1:tag3 xmlns:ns1="NS2" ns1:id="test"/></ns1:tag1>'
     root = parse_function(markup)
@@ -98,9 +98,9 @@ def namespaces(test, parse_function):
     ae(len(xpath('//ns2:tag3')), 1, err)
     ae(len(xpath('//ns1:tag2[@ns1:id="test"]')), 1, err)
     ae(len(xpath('//ns2:tag3[@ns2:id="test"]')), 1, err)
-    for tag in root.iter():
-        if 'NS' in tag.tag:
-            ae('ns1', tag.prefix)
+    # for tag in root.iter():
+    #     if 'NS' in tag.tag:
+    #         ae('ns1', tag.prefix)
 
     markup = '<html xml:lang="en"><body><p lang="de"><p xml:lang="es"><p lang="en" xml:lang="de">'
     root = parse_function(markup)
@@ -108,11 +108,11 @@ def namespaces(test, parse_function):
     ae(len(root.xpath('//*[@lang="en"]')), 2, err)
     ae(len(root.xpath('//*[@lang="de"]')), 1, err)
     ae(len(root.xpath('//*[@lang="es"]')), 1, err)
-    ae(len(XPath('//*[@xml:lang]')(root)), 0, err)
+    # ae(len(XPath('//*[@xml:lang]')(root)), 0, err)
 
 
 def space_characters(test, parse_function):
-    markup = '<html><p>\u000c</p>'
+    markup = '<html><p>\u000cX</p>'
     root = parse_function(markup)
     err = 'form feed character not converted, parsed markup:\n' + etree.tostring(root)
     test.assertNotIn('\u000c', root.xpath('//*[local-name()="p"]')[0].text, err)
@@ -159,6 +159,7 @@ def comments(test, parse_function):
     test.assertEqual(len(XPath('//h:body')(root)), 1, 'Failed to parse with comment containing dashes')
     test.assertEqual(len(tuple(root.iterdescendants(etree.Comment))), 1)
 
+
 basic_checks = (nonvoid_cdata_elements, namespaces, space_characters,
                 case_insensitive_element_names, entities, comments,
                 multiple_html_and_body, attribute_replacement)
